"""Adds s-expression HTML tags to air."""

from fastapi_tags import TagResponse as TagResponse  # noqa
from fastapi_tags import Tag as Tag  # noqa
from fastapi_tags import A as A  # noqa
from fastapi_tags import Abbr as Abbr  # noqa
from fastapi_tags import Address as Address  # noqa
from fastapi_tags import Area as Area  # noqa
from fastapi_tags import Article as Article  # noqa
from fastapi_tags import Aside as Aside  # noqa
from fastapi_tags import Audio as Audio  # noqa
from fastapi_tags import B as B  # noqa
from fastapi_tags import Base as Base  # noqa
from fastapi_tags import Bdi as Bdi  # noqa
from fastapi_tags import Bdo as Bdo  # noqa
from fastapi_tags import Blockquote as Blockquote  # noqa
from fastapi_tags import Body as Body  # noqa
from fastapi_tags import Br as Br  # noqa
from fastapi_tags import Button as Button  # noqa
from fastapi_tags import Canvas as Canvas  # noqa
from fastapi_tags import Caption as Caption  # noqa
from fastapi_tags import Cite as Cite  # noqa
from fastapi_tags import Code as Code  # noqa
from fastapi_tags import Col as Col  # noqa
from fastapi_tags import Colgroup as Colgroup  # noqa
from fastapi_tags import Data as Data  # noqa
from fastapi_tags import Datalist as Datalist  # noqa
from fastapi_tags import Dd as Dd  # noqa
from fastapi_tags import Del as Del  # noqa
from fastapi_tags import Details as Details  # noqa
from fastapi_tags import Dfn as Dfn  # noqa
from fastapi_tags import Dialog as Dialog  # noqa
from fastapi_tags import Div as Div  # noqa
from fastapi_tags import Dl as Dl  # noqa
from fastapi_tags import Dt as Dt  # noqa
from fastapi_tags import Em as Em  # noqa
from fastapi_tags import Embed as Embed  # noqa
from fastapi_tags import Fieldset as Fieldset  # noqa
from fastapi_tags import Figcaption as Figcaption  # noqa
from fastapi_tags import Figure as Figure  # noqa
from fastapi_tags import Footer as Footer  # noqa
from fastapi_tags import Form as Form  # noqa
from fastapi_tags import H1 as H1  # noqa
from fastapi_tags import H2 as H2  # noqa
from fastapi_tags import H3 as H3  # noqa
from fastapi_tags import H4 as H4  # noqa
from fastapi_tags import H5 as H5  # noqa
from fastapi_tags import H6 as H6  # noqa
from fastapi_tags import Head as Head  # noqa
from fastapi_tags import Header as Header  # noqa
from fastapi_tags import Hgroup as Hgroup  # noqa
from fastapi_tags import Hr as Hr  # noqa
from fastapi_tags import Html as Html  # noqa
from fastapi_tags import I as I  # noqa
from fastapi_tags import Iframe as Iframe  # noqa
from fastapi_tags import Img as Img  # noqa
from fastapi_tags import Input as Input  # noqa
from fastapi_tags import Ins as Ins  # noqa
from fastapi_tags import Kbd as Kbd  # noqa
from fastapi_tags import Label as Label  # noqa
from fastapi_tags import Legend as Legend  # noqa
from fastapi_tags import Li as Li  # noqa
from fastapi_tags import Link as Link  # noqa
from fastapi_tags import Main as Main  # noqa
from fastapi_tags import Map as Map  # noqa
from fastapi_tags import Mark as Mark  # noqa
from fastapi_tags import Menu as Menu  # noqa
from fastapi_tags import Meta as Meta  # noqa
from fastapi_tags import Meter as Meter  # noqa
from fastapi_tags import Nav as Nav  # noqa
from fastapi_tags import Noscript as Noscript  # noqa
from fastapi_tags import Object as Object  # noqa
from fastapi_tags import Ol as Ol  # noqa
from fastapi_tags import Optgroup as Optgroup  # noqa
from fastapi_tags import Option as Option  # noqa
from fastapi_tags import Output as Output  # noqa
from fastapi_tags import P as P  # noqa
from fastapi_tags import Param as Param  # noqa
from fastapi_tags import Picture as Picture  # noqa
from fastapi_tags import Pre as Pre  # noqa
from fastapi_tags import Progress as Progress  # noqa
from fastapi_tags import Q as Q  # noqa
from fastapi_tags import Rp as Rp  # noqa
from fastapi_tags import Rt as Rt  # noqa
from fastapi_tags import Ruby as Ruby  # noqa
from fastapi_tags import S as S  # noqa
from fastapi_tags import Samp as Samp  # noqa
from fastapi_tags import Script as Script  # noqa
from fastapi_tags import Search as Search  # noqa
from fastapi_tags import Section as Section  # noqa
from fastapi_tags import Select as Select  # noqa
from fastapi_tags import Small as Small  # noqa
from fastapi_tags import Source as Source  # noqa
from fastapi_tags import Span as Span  # noqa
from fastapi_tags import Strong as Strong  # noqa
from fastapi_tags import Style as Style  # noqa
from fastapi_tags import Sub as Sub  # noqa
from fastapi_tags import Summary as Summary  # noqa
from fastapi_tags import Sup as Sup  # noqa
from fastapi_tags import Svg as Svg  # noqa
from fastapi_tags import Table as Table  # noqa
from fastapi_tags import Tbody as Tbody  # noqa
from fastapi_tags import Td as Td  # noqa
from fastapi_tags import Template as Template  # noqa
from fastapi_tags import Textarea as Textarea  # noqa
from fastapi_tags import Tfoot as Tfoot  # noqa
from fastapi_tags import Th as Th  # noqa
from fastapi_tags import Thead as Thead  # noqa
from fastapi_tags import Time as Time  # noqa
from fastapi_tags import Title as Title  # noqa
from fastapi_tags import Tr as Tr  # noqa
from fastapi_tags import Track as Track  # noqa
from fastapi_tags import U as U  # noqa
from fastapi_tags import Ul as Ul  # noqa
from fastapi_tags import Var as Var  # noqa
from fastapi_tags import Video as Video  # noqa
from fastapi_tags import Wbr as Wbr  # noqa
